# player_amp
### written in Phyton 3.8.1 by Strolch
a little tool written in phyton to count all the active players on your AMP managed game server

1. use player_amp.setserver to save the login data 

2. use player_amp or player_amp.debug to count the active users

3. have FUN or not ;)